==> charcoal-0.3.1.tar.gz: charcoal-0.3.1/charcoal/classes/config_providers/CachedSpycConfigProvider.class.php <==
<?php
/**
*
* YAMLѡSpycˤˤʥå嵡ǽդ
*
* PHP version 5
*
* @package    configs
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
require_once('Cache/Lite.php');

class charcoal_CachedSpycConfigProvider implements charcoal_IConfigProvider
{
	var $_cache;
	var $_config_file;

	/**
	 *    󥹥ȥ饯
	 *
	 * @access    public
	 */
	public function __construct()
	{
		// åǥ쥯ȥ
		$cache_dir = charcoal_ResourceLocator::getPath( charcoal_ResourcePath::TEMP );

		// å奪ץ
		$options = array(
			'cacheDir' => "$cache_dir/",
			'lifeTime' => 999999999,
			'automaticSerialization' => TRUE
		);
		
		// å奪֥
		$this->_cache = new Cache_Lite($options);
	}

	/**
	 * ץХ̾
	 *
	 * @access    public
	 * @return    String
	 */
	public function getProviderName()
	{
		return "Cached Spyc Config Provider";
	}

	/**
	 *
	 *
	 * @access    public
	 * @param     config_name ̾
	 */
	public function load( $config_name )
	{
		$config_file = charcoal_ResourceLocator::getPath( charcoal_ResourcePath::CONFIG, s("$config_name.yml") );

		log_info( "system",  "ե[$config_file]ɤ߹ߤޤ", __FILE__, __LINE__ );

		// å夬뤫
		$cache_data = $this->_cache->get($config_file);
		if ( $cache_data )
		{
			// Ф
			$config = $cache_data;
		}
		else{
			require_once('spyc.php');

			if ( is_file($config_file) )
			{
				// Υ
				$config = Spyc::YAMLLoad($config_file);

				// å¸
				$ret = $this->_cache->save( $config, $config_file );
			}
		}

		log_info( "system",  "ե[$config_file]ɤ߹ߤޤ", __FILE__, __LINE__ );

		return $config;
	}

}

==> charcoal-0.3.2.tar.gz: charcoal-0.3.2/charcoal/classes/config_providers/CachedSpycConfigProvider.class.php <==
<?php
/**
*
* YAMLѡSpycˤˤʥå嵡ǽդ
*
* PHP version 5
*
* @package    configs
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
require_once('Cache/Lite.php');

class charcoal_CachedSpycConfigProvider implements charcoal_IConfigProvider
{
	var $_cache;
	var $_config_file;

	/**
	 *    󥹥ȥ饯
	 *
	 * @access    public
	 */
	public function __construct()
	{
		// åǥ쥯ȥ
		$cache_dir = charcoal_ResourceLocator::getPath( charcoal_ResourcePath::TEMP );

		// å奪ץ
		$options = array(
			'cacheDir' => "$cache_dir/",
			'lifeTime' => 999999999,
			'automaticSerialization' => TRUE
		);
		
		// å奪֥
		$this->_cache = new Cache_Lite($options);
	}

	/**
	 * ץХ̾
	 *
	 * @access    public
	 * @return    String
	 */
	public function getProviderName()
	{
		return "Cached Spyc Config Provider";
	}

	/**
	 *
	 *
	 * @access    public
	 * @param     config_name ̾
	 */
	public function load( $config_root, $config_name )
	{
		$config_file = charcoal_ResourceLocator::getPath( charcoal_ResourcePath::CONFIG, "$config_name.yml" );

		log_info( "system",  "ե[$config_file]ɤ߹ߤޤ", __FILE__, __LINE__ );

		// å夬뤫
		$cache_data = $this->_cache->get($config_file);
		if ( $cache_data )
		{
			// Ф
			$config = $cache_data;
		}
		else{
			require_once('spyc.php');

			if ( is_file($config_file) )
			{
				// Υ
				$config = Spyc::YAMLLoad($config_file);

				// å¸
				$ret = $this->_cache->save( $config, $config_file );
			}
		}

		log_info( "system",  "ե[$config_file]ɤ߹ߤޤ", __FILE__, __LINE__ );

		return $config;
	}

}
